# Change Log
All notable changes to this project will be documented in this file.
 
 
## [0.1.2] - 2021-11-22
 
Add this changelog file for tracking notable changes.
Some fixes on CI/CD pipeline and documentation generator.
New minimal functionalities.
 
### Added
- Changelog file.
  
- Calculation of the average price of the market session.

- Indication if price is below average price of the market session.
 

### Fixed
 
- Fix documentation auto generation.